@@ -4,6 +4,10 @@ pub type Result<T = ()> = std::result::Result<T, Error>;
 pub enum Error {
     #[error("{0}")]
     Http(#[from] reqwest::Error),
-    #[error("{}", .0.error)]
-    Peertube(crate::data::Error),
+    #[error("{0}")]
+    Io(#[from] std::io::Error),
+    #[error("{0}")]
+    Json(#[from] serde_json::Error),
+    #[error("{0}")]
+    Peertube(String),
 }
